import libhoney
import time
from functools import wraps

class HoneycombClient:
    def __init__(self, writekey, dataset, debug=False):
        libhoney.init(writekey=writekey, dataset=dataset, debug=debug)
        self._client = libhoney

    def send_event(self, fields: dict):
        ev = self._client.new_event()
        for k, v in fields.items():
            ev.add_field(k, v)
        ev.send()
        self._client.flush()

    def timed(self, extra_fields=None, event_arg='event'):
        """
        Decorator to time a function and send a Honeycomb event.
        Passes a libhoney event object as a kwarg (default: 'event').
        Usage:
            @honey.timed({"alert_name": "my_func"})
            def my_func(..., event=None):
                event.add_field("key", value)
            
            @honey.timed({"alert_name": "my_func"}, event_arg='track')
            def my_func(..., track=None):
                track.add_field("key", value)
        """
        extra_fields = extra_fields or {}
        def decorator(func):
            @wraps(func)
            def wrapper(*args, **kwargs):
                start = time.time()
                ev = self._client.new_event()
                for k, v in extra_fields.items():
                    ev.add_field(k, v)
                kwargs[event_arg] = ev
                try:
                    result = func(*args, **kwargs)
                    return result
                finally:
                    duration_ms = (time.time() - start) * 1000
                    ev.add_field("duration_ms", duration_ms)
                    ev.add_field("function_name", func.__name__)
                    ev.send()
                    self._client.flush()
            return wrapper
        return decorator



import unittest
from unittest.mock import patch, MagicMock
from capture_hc.honeycomb_client import HoneycombClient

class TestHoneycombClient(unittest.TestCase):
    @patch('capture_hc.honeycomb_client.libhoney')
    def test_send_event(self, mock_libhoney):
        client = HoneycombClient('fakekey', 'fakedataset')
        mock_event = MagicMock()
        mock_libhoney.new_event.return_value = mock_event
        fields = {'foo': 'bar', 'baz': 123}
        client.send_event(fields)
        mock_libhoney.new_event.assert_called_once()
        for k, v in fields.items():
            mock_event.add_field.assert_any_call(k, v)
        mock_event.send.assert_called_once()
        mock_libhoney.flush.assert_called_once()

    @patch('capture_hc.honeycomb_client.libhoney')
    def test_timed_decorator(self, mock_libhoney):
        client = HoneycombClient('fakekey', 'fakedataset')
        mock_event = MagicMock()
        mock_libhoney.new_event.return_value = mock_event
        extra_fields = {'alert_name': 'test_func'}
        @client.timed(extra_fields)
        def dummy(event=None):
            event.add_field('custom', 42)
            return 'done'
        result = dummy()
        self.assertEqual(result, 'done')
        mock_libhoney.new_event.assert_called_once()
        mock_event.add_field.assert_any_call('alert_name', 'test_func')
        mock_event.add_field.assert_any_call('custom', 42)
        mock_event.add_field.assert_any_call('duration_ms', unittest.mock.ANY)
        mock_event.add_field.assert_any_call('function_name', 'dummy')
        mock_event.send.assert_called_once()
        mock_libhoney.flush.assert_called_once()

if __name__ == '__main__':
    unittest.main() 


from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

with open(here / "README.md", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="capture_hc",
    version="0.1.1",
    description="A simple, user-friendly Python client for sending events and traces to Honeycomb, with decorator support for timing and custom fields.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Amit Singh Sansoya",
    author_email="tusharamit@yahoo.com",
    maintainer="Amit Singh Sansoya",
    maintainer_email="tusharamit@yahoo.com",
    url="https://github.com/yourusername/capture_hc",  # Update with actual repo if available
    packages=find_packages(),
    install_requires=["libhoney"],
    python_requires=">=3.6",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    include_package_data=True,
)
